==> nextcloud-app-deck-1:1.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/et_EE.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "%s on %s" : "%s %s-l",
    "Finished" : "Lõpetatud",
    "Later" : "Hiljem",
    "copy" : "koopia",
    "Done" : "Valmis",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "No file uploaded or file size exceeds maximum of %s" : "Faili ei laaditud üles või selle suurus ületab maksimaalse %s",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "Cancel" : "Loobu",
    "File already exists" : "Fail on juba olemas",
    "Open" : "Ava",
    "Completed" : "Lõpetatud",
    "Details" : "Üksikasjad",
    "Sharing" : "Jagamine",
    "Tags" : "Sildid",
    "Activity" : "Tegevus",
    "Undo" : "Tühista",
    "Can edit" : "Võib redigeerida",
    "Can share" : "Can share",
    "Owner" : "Omanik",
    "Delete" : "Kustuta",
    "Edit" : "Redigeeri",
    "Download" : "Lae alla",
    "Comments" : "Kommentaarid",
    "Modified" : "Muudetud",
    "Created" : "Loodud",
    "Save" : "Salvesta",
    "Reply" : "Vasta",
    "Update" : "Uuenda",
    "Created:" : "Loodud:",
    "Description" : "Kirjeldus",
    "(group)" : "(grupp)",
    "Delete card" : "Kustuta kaart",
    "seconds ago" : "sekundit tagasi",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Keyboard shortcut" : "Klaviatuuri otsetee",
    "Search" : "Otsi",
    "Shared with you" : "Sinuga jagatud",
    "Cancel edit" : "Loobu muutmisest",
    "No notifications" : "Märguandeid pole",
    "An error occurred" : "Tekkis tõrge",
    "Advanced options" : "Täpsemad valikud",
    "Today" : "Täna",
    "Tomorrow" : "Homme",
    "Close" : "Sulge",
    "Share" : "Jaga",
    "Personal" : "Isiklik"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1:1.15.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/et_EE.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "%s on %s" : "%s %s-l",
    "Finished" : "Lõpetatud",
    "Later" : "Hiljem",
    "copy" : "koopia",
    "To Do" : "Tegemiseks",
    "Done" : "Valmis",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaetud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaetud fail on suurem, kui MAX_FILE_SIZE atribuut, mis seadistati HTML vormis",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei latud üles",
    "Missing a temporary folder" : "Ajutine kausta on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "No file uploaded or file size exceeds maximum of %s" : "Faili ei laaditud üles või selle suurus ületab maksimaalse %s",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "Cancel" : "Loobu",
    "File already exists" : "Fail on juba olemas",
    "Add list" : "Lisa loend",
    "List name" : "Nimekirja nimi",
    "Active filters" : "Aktiivsed filtrid",
    "Open" : "Ava",
    "Completed" : "Lõpetatud",
    "Clear filter" : "Tühjenda filter",
    "Open details" : "Ava üksikasjad",
    "Details" : "Üksikasjad",
    "Sharing" : "Jagamine",
    "Tags" : "Sildid",
    "Activity" : "Tegevus",
    "Undo" : "Tühista",
    "Transfer" : "Teisalda",
    "Can edit" : "Võib redigeerida",
    "Can share" : "Can share",
    "Owner" : "Omanik",
    "Delete" : "Kustuta",
    "Delete list" : "Kustuta loend",
    "Edit" : "Redigeeri",
    "Members" : "Liikmed",
    "Invalid path selected" : "Vigane asukoht on valitud",
    "Upload new files" : "Laadi uued failid üles",
    "Share from Files" : "Jaga failirakendusest",
    "Pending share" : "Ootel jagamine",
    "Add this attachment" : "Lisa see manus",
    "Show in Files" : "Näita failirakenduses",
    "Download" : "Laadi alla",
    "Remove attachment" : "Eemalda manus",
    "Delete Attachment" : "Kustuta manus",
    "Restore Attachment" : "Taasta manus",
    "Modified" : "Muudetud",
    "Created" : "Loodud",
    "The title cannot be empty." : "Pealkiri ei saa olla tühi.",
    "Open in sidebar view" : "Ava külgriba vaates",
    "Open in bigger view" : "Ava suuremas vaates",
    "Attachments" : "Manused",
    "Comments" : "Kommentaarid",
    "Save" : "Salvesta",
    "Created:" : "Loodud:",
    "Cancel reply" : "Katkesta vastamine",
    "Reply" : "Vasta",
    "Update" : "Uuenda",
    "Description" : "Kirjeldus",
    "Mark as done" : "Märgi tehtuks",
    "(group)" : "(grupp)",
    "Edit title" : "Muuda pealkirja",
    "Delete card" : "Kustuta kaart",
    "seconds ago" : "sekundit tagasi",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Keyboard shortcut" : "Klaviatuuri otsetee",
    "Action" : "Tegevus",
    "Shift" : "Nihuta",
    "Ctrl" : "Ctrl",
    "Search" : "Otsi",
    "Shared with you" : "Sinuga jagatud",
    "Cancel edit" : "Loobu muutmisest",
    "No reminder" : "Meeldetuletust pole",
    "An error occurred" : "Tekkis tõrge",
    "No notifications" : "Märguandeid pole",
    "Advanced options" : "Täpsemad valikud",
    "Today" : "Täna",
    "Tomorrow" : "Homme",
    "No results found" : "Otsingutulemusi ei leidu",
    "Due on {date}" : "Tähtaeg: {date}",
    "Close" : "Sulge",
    "Error creating the share" : "Viga jaosmeedia loomisel",
    "Share" : "Jaga",
    "Personal" : "Isiklik"
},
"nplurals=2; plural=(n != 1);");
